@@ -193,6 +193,7 @@ enum general
     General_Audio_Format_WithHint_List,
     General_Audio_Codec_List,
     General_Audio_Language_List,
+    General_Audio_Channels_Total,
     General_Text_Format_List,
     General_Text_Format_WithHint_List,
     General_Text_Codec_List,
@@ -263,7 +264,19 @@ enum general
     General_Duration_String4,
     General_Duration_String5,
     General_Duration_Start,
+    General_Duration_Start_String,
+    General_Duration_Start_String1,
+    General_Duration_Start_String2,
+    General_Duration_Start_String3,
+    General_Duration_Start_String4,
+    General_Duration_Start_String5,
     General_Duration_End,
+    General_Duration_End_String,
+    General_Duration_End_String1,
+    General_Duration_End_String2,
+    General_Duration_End_String3,
+    General_Duration_End_String4,
+    General_Duration_End_String5,
     General_OverallBitRate_Mode,
     General_OverallBitRate_Mode_String,
     General_OverallBitRate,
@@ -346,6 +359,9 @@ enum general
     General_Part,
     General_Part_Position,
     General_Part_Position_Total,
+    General_Reel,
+    General_Reel_Position,
+    General_Reel_Position_Total,
     General_Track,
     General_Track_More,
     General_Track_Url,
@@ -458,6 +474,7 @@ enum general
     General_BPM,
     General_ISRC,
     General_ISBN,
+    General_ISAN,
     General_BarCode,
     General_LCCN,
     General_CatalogNumber,
