@@ -225,6 +225,7 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxx_btrt();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_ccst();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_chan();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_chnl();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_clap();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_clli();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_colr();
@@ -256,12 +257,15 @@ private :
     void moov_trak_mdia_minf_stbl_stsd_xxxx_mdcv();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_mhaC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_pasp();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_pcmC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_SA3D();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_sinf();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_sinf_frma();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_sinf_imif();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_sinf_schm();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_sinf_schi();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_udts();
+    void moov_trak_mdia_minf_stbl_stsd_xxxx_vvcC();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_wave();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_wave_acbf();
     void moov_trak_mdia_minf_stbl_stsd_xxxx_wave_dec3() {moov_trak_mdia_minf_stbl_stsd_xxxx_dec3();}
@@ -439,6 +443,7 @@ private :
     std::vector<std::vector<int32u> >       meta_iprp_ipma_Entries;
     int8u*                                  meta_iprp_ipco_Buffer;
     size_t                                  meta_iprp_ipco_Buffer_Size; //Used as property_index if no buffer
+    int16u                                  channelcount;
     int8u                                   Version_Temp; //Used when box version must be provided to nested boxes
 
     //Data
@@ -519,6 +524,8 @@ private :
         bool                    HasForcedSamples;
         bool                    AllForcedSamples;
         bool                    IsImage;
+        bool                    tkhd_Found;
+        int32u                  TrackID;
         std::vector<int32u>     CC;
         std::vector<int32u>     CCFor;
         std::vector<int32u>     FallBackTo;
@@ -561,6 +568,7 @@ private :
         #endif //MEDIAINFO_DEMUX
         #if MEDIAINFO_CONFORMANCE
             bool                stss_IsPresent;
+            bool                sbgp_IsPresent;
             std::vector<sgpd_prol_struct> sgpd_prol;
             std::vector<sbgp_struct> sbgp;
             int8u               default_sample_is_non_sync_sample_PresenceAndValue;
@@ -572,7 +580,7 @@ private :
             MI=NULL;
             TimeCode=NULL;
             StreamKind=Stream_Max;
-            StreamPos=0;
+            StreamPos=(size_t)-1;
             hdlr_Type=0x00000000;
             hdlr_SubType=0x00000000;
             hdlr_Manufacturer=0x00000000;
@@ -612,6 +620,7 @@ private :
             HasForcedSamples=false;
             AllForcedSamples=false;
             IsImage=false;
+            tkhd_Found=false;
             CleanAperture_Width=0;
             CleanAperture_Height=0;
             CleanAperture_PixelAspectRatio=0;
@@ -628,6 +637,7 @@ private :
             #endif //MEDIAINFO_DEMUX
             #if MEDIAINFO_CONFORMANCE
                 stss_IsPresent=false;
+                sbgp_IsPresent=false;
                 default_sample_is_non_sync_sample_PresenceAndValue=0;
                 FirstOutputtedDecodedSample=0;
             #endif
